pub enum WireError {
VarintTooLong,
UnexpectedEof {
offset: usize,
},
InvalidMagic {
found: u32,
},
UnsupportedVersion {
major: u8,
minor: u8,
},
ReservedNonZero {
offset: usize,
value: u8,
},
InvalidBlockType {
raw: u64,
},
Io(Error),
}Variants
VarintTooLong
Varint encoding exceeded 10 bytes without terminating.
UnexpectedEof
Input ended before a complete varint or header could be read.
InvalidMagic
Magic number did not match “BCP\0”.
UnsupportedVersion
Unsupported format version.
ReservedNonZero
Reserved field was non-zero.
InvalidBlockType
Block type varint decoded to a value that does not fit in a u8.
Io(Error)
I/O error during read or write.